This is a file of people that have made significant contributions to the Substra sdk. It is sorted in chronological order. Please include your contribution at the bottom of this document in the following format : name (N), email (E), description of work (W) and date (D).

To have your contribution listed, your work must meet the minimum [threshold of originality](https://en.wikipedia.org/wiki/Threshold_of_originality), which will be evaluated by the maintainers of the repository.

Thank you for your contribution, your work is greatly appreciated !

—-- Example —--

- N: John Doe
- E: john.doe@owkin.com
- W: Integrated new feature
- D: 02/02/2023

---

Copyright (c) 2018-present Owkin Inc. All rights reserved.

All other contributions:
Copyright (c) 2023 to the respective contributors.
All rights reserved.
